package com.huawei.nlp.demo;

import com.huawei.nlp.client.NlpfClient;
import com.huawei.nlp.client.auth.AuthInfo;
import com.huawei.nlp.client.auth.AuthMode;
import com.huawei.nlp.client.constant.SegmentConstant;
import com.huawei.nlp.client.exception.NlpException;
import com.huawei.nlp.restapi.JSON;
import com.huawei.nlp.restapi.model.EntityLinkingReq;
import com.huawei.nlp.restapi.model.EntityLinkingResp;
import com.huawei.nlp.restapi.model.KeywordExtractionReq;
import com.huawei.nlp.restapi.model.KeywordExtractionResp;
import com.huawei.nlp.restapi.model.MultiGrainedSegmentReq;
import com.huawei.nlp.restapi.model.MultiGrainedSegmentResp;
import com.huawei.nlp.restapi.model.NerReq;
import com.huawei.nlp.restapi.model.NerResp;
import com.huawei.nlp.restapi.model.SegmentReq;
import com.huawei.nlp.restapi.model.SegmentResp;
import com.huawei.nlp.restapi.model.SentenceVectorsReq;
import com.huawei.nlp.restapi.model.SentenceVectorsResp;
import com.huawei.nlp.restapi.model.TextSimilarityReq;
import com.huawei.nlp.restapi.model.TextSimilarityResp;
import net.sf.json.util.JSONUtils;

import java.util.ArrayList;
import java.util.List;

public class NlpfDemo {

    /**
     * 以下参数为例子，不能直接正常使用，需用户替换为自己的参数
     * ak 用户自己的ak
     * sk 用户自的sk
     * serviceRegion 用户所在的服务区域，cn-north-4表示北京四
     * projectId 用户自己的项目id，参考官网获取教程
     */
    private static AuthInfo authInfo = new AuthInfo("QTWAOYTTINDU2KYUC","MFyfvK41ba2gqM7Uio6PznpdUKGpownRZmHc",
      "cn-north-4","MFyfvK43s1ba2giqM7Uio6PznpdUKGpownRZm2");
    private static NlpfClient nlpfClient = new NlpfClient(AuthMode.AKSK,authInfo);
  /**
   * 分词接口例子
   */
    public static void segmentDemo() {
        SegmentReq req = new SegmentReq();
        req.setText("今天天气真好");
      //选填，SegmentConstant.POS_SWITCH_ON 开启词性标注 SegmentConstant.POS_SWITCH_OFF不开启
        req.setPosSwitch(SegmentConstant.POS_SWITCH_ON);
        //选填，默认为zh，表示中文，目前只支持中文
        req.setLang("zh");
        //选填,支持的分词规范，支持的分词规范，目前支持PKU（北大分词标准）、CTB（宾州树库标准），默认为PKU
        req.setCriterion("PKU");

        try {
            SegmentResp resp = nlpfClient.segment(req);
        } catch (NlpException e) {
            //失败统一以异常形式抛出，异常类见异常类说明。客户端自行处理异常
            e.printStackTrace();
        }
    }

    /**
     * 命名实体识别（基础版）例子
     */
    public static void nerDemo() {
        NerReq req = new NerReq();
        //text为识别文本，必填
        req.setText("张三买电脑");
        //选填，zh表示中文
        req.setLang("zh");
        try {
            NerResp resp = nlpfClient.ner(req);
        } catch (NlpException e) {
            e.printStackTrace();
        }
    }

    /**
     * 命名实体识别（领域版）例子
     */
    public static void nerDomainDemo() {
        NerReq req = new NerReq();
        //text为识别文本，必填
        req.setText("张三买电脑");
        //选填，zh表示中文
        req.setLang("zh");
        try {
            NerResp resp = nlpfClient.domainNer(req);
        } catch (NlpException e) {
            //失败统一以异常形式抛出，详情见异常类说明。客户端自行处理异常
            e.printStackTrace();
        }
    }

    /**
     * 文本相似度例子
     */
    public static void getTextSimilarityDemo() {
        TextSimilarityReq req = new TextSimilarityReq();
        //相似度对比的两个文本
        req.setText1("今天天气晴朗");
        req.setText2("今天天气晴");
        //支持的文本语言类型，zh表示中文，目前只支持中文
        req.setLang("zh");
        try {
          System.out.println("文本1:" + req.getText1());
          System.out.println("文本2:" + req.getText2());
          TextSimilarityResp resp = nlpfClient.getTextSimilarity(req);
          System.out.println("相似度结果:" + resp.getSimilarity());
        } catch (NlpException e) {
            //失败统一以异常形式抛出，详情见异常类说明。客户端自行处理异常
            e.printStackTrace();
        }
    }

    /**
     * 句向量例子
     */
    public static void getSentenceVectorsDemo() {
        SentenceVectorsReq req = new SentenceVectorsReq();
        //构造需要获得句向量的句子
        List<String> sentences = new ArrayList<String>();
        sentences.add("今天张三来北京了");
        sentences.add("今天李四来北京了");
        req.setSentences(sentences);
        //模型名，目前只支持general
        req.setDomain("general");
        try {
            SentenceVectorsResp resp = nlpfClient.getSentenceVectors(req);
        } catch (NlpException e) {
            //失败统一以异常形式抛出，详情见异常类说明。客户端自行处理异常
        }
    }

    /**
     * 多粒度分词例子
     */
    public static void multiGrainedSegment() {
        MultiGrainedSegmentReq req = new MultiGrainedSegmentReq();
        req.setText("华为技术有限公司的总部");
        req.setLang("zh");
        try {
            MultiGrainedSegmentResp resp = nlpfClient.multiGrainedSegment(req);
        } catch (NlpException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 关键词抽取例子
     */
    public static void extractKeyword() {
        KeywordExtractionReq req = new KeywordExtractionReq();
        req.setText("华为技术有限公司成立于1987年，总部位于广东省深圳市龙岗区。华为是全球领先的信息与通信技术（ICT）解决方案供应商，专注于ICT领域，坚持稳健经营、持续创新、开放合作，在电信运营商、企业、终端和云计算等领域构筑了端到端的解决方案优势，为运营商客户、企业客户和消费者提供有竞争力的ICT解决方案、产品和服务，并致力于实现未来信息社会、构建更美好的全联接世界。");
        req.setLang("zh");
        req.setLimit(8);
        try {
            KeywordExtractionResp resp = nlpfClient.extractKeyword(req);
        } catch (NlpException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 实体链接例子
     */
    public static void getEntityLinking() {
        EntityLinkingReq req = new EntityLinkingReq();
        req.setText("李娜唱的青藏高原真好听");
        req.setLang("zh");
        try {
            EntityLinkingResp resp = nlpfClient.getEntityLinking(req);
        } catch (NlpException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * Main函数
     */
    public static void main(String []args) {
        NlpfDemo.segmentDemo();
        NlpfDemo.extractKeyword();
        NlpfDemo.getEntityLinking();
        NlpfDemo.getSentenceVectorsDemo();
        System.out.println("                                                                                ");
      System.out.println("                                                                                ");

      System.out.println("                                                                                ");

      System.out.println("                                                                                ");
      System.out.println("                                                                                ");
      System.out.println("                                                                                ");
      System.out.println("                                                                                ");
      System.out.println("                                                                                ");
      System.out.println("                                                                                ");

      NlpfDemo.getTextSimilarityDemo();
        NlpfDemo.multiGrainedSegment();
        NlpfDemo.nerDomainDemo();
    }
}
