package com.huawei.nlp.demo;

import com.huawei.nlp.client.NluClient;
import com.huawei.nlp.client.auth.AuthInfo;
import com.huawei.nlp.client.auth.AuthMode;
import com.huawei.nlp.client.constant.ClassifyDomainConstant;
import com.huawei.nlp.client.constant.SentimentDomainConstant;
import com.huawei.nlp.client.exception.NlpException;
import com.huawei.nlp.restapi.model.ClassifyReq;
import com.huawei.nlp.restapi.model.ClassifyResp;
import com.huawei.nlp.restapi.model.GeneralSentimentReq;
import com.huawei.nlp.restapi.model.GeneralSentimentResp;
import com.huawei.nlp.restapi.model.IntentReq;
import com.huawei.nlp.restapi.model.IntentResp;

public class NluDemo {

    /**
     * 以下参数为例子，不能直接正常使用，需用户替换为自己的参数
     * ak 用户自己的ak
     * sk 用户自的sk
     * serviceRegion 用户所在的服务区域，cn-north-4表示北京四
     * projectId 用户自己的项目id，参考官网获取教程
     */
    private static AuthInfo authInfo = new AuthInfo("QTWAOYTTINDUT2QVKYUC","MFyfvK41ba2giqM7Uio6PznpdUKGpownRZmHc",
        "cn-north-4","MFyfvK43s1ba2giqM7Uio6PznpdUKGpownRZm22Hc");
    private static NluClient nluClient = new NluClient(AuthMode.AKSK,authInfo);

    /**
     * 情感分析（基础版）例子
     */
    public static void getSentimentDemo() {
        GeneralSentimentReq req = new GeneralSentimentReq();
        req.setContent("浑浑噩噩的头脑、失魂落魄的身体…");

        try {
            GeneralSentimentResp resp = nluClient.getSentiment(req);
        } catch (NlpException e) {
            //失败统一以异常形式抛出，详情见异常类说明.客户端自行处理异常
            e.printStackTrace();
        }
    }

    /**
     * 情感分析（领域版）例子
     */
    public static void getDomainSentimentDemo() {
        GeneralSentimentReq req = new GeneralSentimentReq();
        req.setContent("很不错的一款车，可以改变生活方式。");
        //领域类型，常量 SentimentDomainConstant.DOMAIN_TYPE_CAR 表示汽车领域，值为2
        //常量SentimentDomainConstant.DOMAIN_TYPE_E_COMMERCE 表示电商领域，值为1
        req.setType(SentimentDomainConstant.DOMAIN_TYPE_CAR);

        try {
            GeneralSentimentResp resp = nluClient.getDomainSentiment(req);
        } catch (NlpException e) {
            //失败统一以异常形式抛出，详情见异常类说明。客户端自行处理异常
            e.printStackTrace();
        }
    }

    /**
     * 文本分类例子
     */
    public static void classifyTextDemo() {
        ClassifyReq req = new ClassifyReq();
        req.setContent("XXX去屑洗发水，全国包邮");
        //分类领域类型，ClassifyDomainConstant.DOMAIN_TYPE_AD 表示广告，值为1。目前只支持广告
        req.setDomain(ClassifyDomainConstant.DOMAIN_TYPE_AD);

        try {
            ClassifyResp resp = nluClient.classifyText(req);
        } catch (NlpException e) {
            //失败统一以异常形式抛出，详情见异常类说明。客户端自行处理异常
            e.printStackTrace();
        }
    }

    /**
     * 意图理解例子
     */
    public static void getIntentDemo() {
        IntentReq req = new IntentReq();
        req.setText("来一首周杰伦的青花瓷");
        //zh表示中文，目前只支持中文
        req.setLang("zh");
        try {
            IntentResp resp = nluClient.getIntent(req);
        } catch (NlpException e) {
            //失败统一以异常形式抛出，详情见异常类说明。客户端自行处理异常
            e.printStackTrace();
        }
    }

    /**
     * Main函数
     */
    public static void main(String []args) {
        NluDemo.classifyTextDemo();
        NluDemo.getDomainSentimentDemo();
        NluDemo.getIntentDemo();
        NluDemo.getSentimentDemo();
    }
}
